@@ -42,6 +42,7 @@ if sys.version_info[0] >= 3:
 # Recommended minimum versions
 from distutils.version import LooseVersion
 minimum_numpy_version = LooseVersion('1.7.0')
+present_numpy_version = LooseVersion(np.__version__)
 
 class test_numexpr(TestCase):
     """Testing with 1 thread"""
@@ -810,9 +811,14 @@ class test_strings(TestCase):
         str_list = [
             b'\0\0\0', b'\0\0foo\0', b'\0\0foo\0b', b'\0\0foo\0b\0',
             b'foo\0', b'foo\0b', b'foo\0b\0', b'foo\0bar\0baz\0\0']
+        min_tobytes_version = LooseVersion('1.9.0')
         for s in str_list:
             r = evaluate('s')
-            self.assertEqual(s, r.tostring())  # check *all* stored data
+            if present_numpy_version >= min_tobytes_version:
+                self.assertEqual(s, r.tobytes())  # check *all* stored data
+            else:
+                # ndarray.tostring() is deprecated as of NumPy 1.19
+                self.assertEqual(s, r.tostring())  # check *all* stored data
 
     def test_compare_copy(self):
         sarr = self.str_array1
@@ -964,6 +970,7 @@ class test_threading_config(TestCase):
         script = '\n'.join([
                 "import os",
                 "if 'NUMEXPR_MAX_THREADS' in os.environ: os.environ.pop('NUMEXPR_MAX_THREADS')",
+                "if 'OMP_NUM_THREADS' in os.environ: os.environ.pop('OMP_NUM_THREADS')",
                 "import numexpr",
                 "assert(numexpr.nthreads <= 8)",
                 "exit(0)"])
@@ -990,6 +997,16 @@ class test_threading_config(TestCase):
         with _environment('OMP_NUM_THREADS', '5'):
             self.assertEqual(5, numexpr._init_num_threads())
 
+    def test_vml_threads_round_trip(self):
+        n_threads = 3
+        if use_vml:
+            numexpr.utils.set_vml_num_threads(n_threads)
+            set_threads = numexpr.utils.get_vml_num_threads()
+            self.assertEqual(n_threads, set_threads)
+        else:
+            self.assertIsNone(numexpr.utils.set_vml_num_threads(n_threads))
+            self.assertIsNone(numexpr.utils.get_vml_num_threads())
+
 
 # Case test for threads
 class test_threading(TestCase):
